searchData={"items":[{"type":"module","title":"FastRSS","doc":"Parse RSS quickly using a Rust NIF.","ref":"FastRSS.html"},{"type":"function","title":"FastRSS.parse/1","doc":"Parse a RSS string into a map.\n\nsoft deprecated: \"Use FastRSS.parse_rss/1 instead\"\n@doc since: \"0.5.0\"\n@deprecated \"Use FastRSS.parse_rss/1 instead\"","ref":"FastRSS.html#parse/1"},{"type":"function","title":"FastRSS.parse_atom/1","doc":"Parse a Atom string into a map.","ref":"FastRSS.html#parse_atom/1"},{"type":"function","title":"FastRSS.parse_rss/1","doc":"Parse a RSS string into a map.","ref":"FastRSS.html#parse_rss/1"},{"type":"extras","title":"README","doc":"Parse RSS feeds very quickly  \n \n       \n       \n       \n       \n       \n \n\n \n   Intro \n  |\n   Compatibility \n  |\n   Installation \n  |\n   Usage \n  |\n   Benchmarks \n  |\n   Deploying \n  |\n   License \n \n\n---","ref":"readme.html"},{"type":"extras","title":"Intro - README","doc":"Parse RSS feeds very quickly\n\n- This is rust NIF built using [rustler](https://github.com/rusterlium/rustler)\n- Uses the [RSS](https://crates.io/crates/rss) rust crate to do the actual RSS parsing\n\n**Speed**\n\nCurrently this is already much faster than most of the pure elixir/erlang packages out there. In benchmarks there are speed improvements anywhere between **6.12x - 50.09x** over the next fastest package ([feeder_ex](https://github.com/manukall/feeder_ex)) that was tested.\n\nCompared to the slowest elixir options tested ([feed_raptor](https://github.com/merongivian/feedraptor), [elixir_feed_parser](https://github.com/fdietz/elixir-feed-parser)), FastRSS was sometimes **259.91x** faster and used **5,412,308.17x** less memory _(0.00156 MB vs 8423.70 MB)_.\n\nSee full [benchmarks](#benchmark) below:","ref":"readme.html#intro"},{"type":"extras","title":"Compatibility - README","doc":"FastRSS requires a minimum combination of Elixir 1.6.0 and Erlang/OTP 20.0, and is tested with a maximum combination of Elixir 1.11.1 and Erlang/OTP 22.0.","ref":"readme.html#compatibility"},{"type":"extras","title":"Installation - README","doc":"This package is available on [hex](https://hex.pm/packages/fast_rss).\n\nIt can be installed by adding `fast_rss` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fast_rss, \"~> 0.5.0\"}\n  ]\nend\n```\n\nYou also need the rust compiler installed: https://www.rust-lang.org/tools/install\n\n```bash\ncurl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"There is only two functions, one for parsing rss `parse_rss/1` and one for parsing atom feeds `parse_atom/1` they takes a string and outputs an `{:ok, map()}` with string keys.\n\n```elixir\niex(1)>  {:ok, map_of_rss} = FastRSS.parse_rss(\"...rss_feed_string...\")\niex(2)> Map.keys(map_of_rss)\n[\"categories\", \"cloud\", \"copyright\", \"description\", \"docs\", \"dublin_core_ext\",\n \"extensions\", \"generator\", \"image\", \"items\", \"itunes_ext\", \"language\",\n \"last_build_date\", \"link\", \"managing_editor\", \"namespaces\", \"pub_date\",\n \"rating\", \"skip_days\", \"skip_hours\", \"syndication_ext\", \"text_input\", \"title\",\n \"ttl\", \"webmaster\"]\n```\n\nThe docs can be found at [https://hexdocs.pm/fast_rss](https://hexdocs.pm/fast_rss).\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Supported Feeds - README","doc":"Reading from the following RSS versions is supported:\n\n- RSS 0.90\n- RSS 0.91\n- RSS 0.92\n- RSS 1.0\n- RSS 2.0\n- iTunes\n- Dublin Core\n- Atom","ref":"readme.html#supported-feeds"},{"type":"extras","title":"Benchmark - README","doc":"HTML: [https://avencera.github.io/fast_rss/](https://avencera.github.io/fast_rss/)\n\nBenchmark run from 2020-02-22 05:23:47.524699Z UTC\n\n#","ref":"readme.html#benchmark"},{"type":"extras","title":"System - README","doc":"Benchmark suite executing on the following system:\n\n \n   \n     Operating System \n     macOS \n    \n     CPU Information \n     Intel(R) Core(TM) i9-9880H CPU @ 2.30GHz \n    \n     Number of Available Cores \n     16 \n    \n     Available Memory \n     32 GB \n    \n     Elixir Version \n     1.10.1 \n    \n     Erlang Version \n     22.2.6 \n   \n \n\n#","ref":"readme.html#system"},{"type":"extras","title":"Configuration - README","doc":"Benchmark suite executing with the following configuration:\n\n \n   \n     :time \n     30 s \n    \n     :parallel \n     1 \n    \n     :warmup \n     5 s \n   \n \n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"Statistics - README","doc":"**Input: anxiety**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     188.57 \n     5.30 ms \n     ±8.26% \n     5.45 ms \n     6.43 ms \n   \n   \n     feeder_ex \n     3.70 \n     269.92 ms \n     ±5.34% \n     268.12 ms \n     316.12 ms \n   \n   \n     feed_raptor \n     2.99 \n     334.01 ms \n     ±2.44% \n     331.03 ms \n     371.28 ms \n   \n   \n     elixir_feed_parser \n     1.94 \n     515.72 ms \n     ±1.94% \n     516.10 ms \n     536.05 ms \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     188.57 \n     &nbsp; \n   \n   \n     feeder_ex \n     3.70 \n     50.9x \n   \n   \n     feed_raptor \n     2.99 \n     62.99x \n   \n   \n     elixir_feed_parser \n     1.94 \n     97.25x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00156 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     17.21 MB \n     11004.73x \n   \n   \n     feed_raptor \n     268.53 MB \n     171693.91x \n   \n   \n     elixir_feed_parser \n     313.30 MB \n     200316.09x \n   \n \n \n\n**Input: ben**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     83.95 \n     11.91 ms \n     ±10.29% \n     12.23 ms \n     16.17 ms \n   \n   \n     feeder_ex \n     13.33 \n     75.04 ms \n     ±4.38% \n     74.21 ms \n     89.72 ms \n   \n   \n     elixir_feed_parser \n     3.52 \n     284.18 ms \n     ±3.89% \n     283.83 ms \n     324.08 ms \n   \n   \n     feed_raptor \n     0.48 \n     2078.76 ms \n     ±0.52% \n     2076.27 ms \n     2097.44 ms \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     83.95 \n     &nbsp; \n   \n   \n     feeder_ex \n     13.33 \n     6.3x \n   \n   \n     elixir_feed_parser \n     3.52 \n     23.86x \n   \n   \n     feed_raptor \n     0.48 \n     174.51x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00155 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     27.86 MB \n     17990.96x \n   \n   \n     elixir_feed_parser \n     163.88 MB \n     105811.88x \n   \n   \n     feed_raptor \n     1577.41 MB \n     1018492.36x \n   \n \n \n\n**Input: daily**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     32.98 \n     0.0303 s \n     ±7.62% \n     0.0313 s \n     0.0339 s \n   \n   \n     feeder_ex \n     4.94 \n     0.20 s \n     ±4.61% \n     0.199 s \n     0.24 s \n   \n   \n     elixir_feed_parser \n     0.64 \n     1.57 s \n     ±1.50% \n     1.57 s \n     1.63 s \n   \n   \n     feed_raptor \n     0.127 \n     7.88 s \n     ±0.23% \n     7.88 s \n     7.90 s \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     32.98 \n     &nbsp; \n   \n   \n     feeder_ex \n     4.94 \n     6.68x \n   \n   \n     elixir_feed_parser \n     0.64 \n     51.86x \n   \n   \n     feed_raptor \n     0.127 \n     259.91x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00153 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     109.73 MB \n     71555.78x \n   \n   \n     elixir_feed_parser \n     880.51 MB \n     574178.95x \n   \n   \n     feed_raptor \n     6386.12 MB \n     4164382.64x \n   \n \n \n\n**Input: dave**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     407.08 \n     2.46 ms \n     ±9.83% \n     2.41 ms \n     3.16 ms \n   \n   \n     feeder_ex \n     56.52 \n     17.69 ms \n     ±6.14% \n     17.37 ms \n     22.51 ms \n   \n   \n     elixir_feed_parser \n     8.90 \n     112.31 ms \n     ±4.12% \n     111.93 ms \n     127.60 ms \n   \n   \n     feed_raptor \n     1.59 \n     628.45 ms \n     ±1.60% \n     626.71 ms \n     656.74 ms \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     407.08 \n     &nbsp; \n   \n   \n     feeder_ex \n     56.52 \n     7.2x \n   \n   \n     elixir_feed_parser \n     8.90 \n     45.72x \n   \n   \n     feed_raptor \n     1.59 \n     255.83x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00157 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     9.25 MB \n     5886.17x \n   \n   \n     elixir_feed_parser \n     80.42 MB \n     51170.23x \n   \n   \n     feed_raptor \n     571.18 MB \n     363425.45x \n   \n \n \n\n**Input: sleepy**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     760.30 \n     1.32 ms \n     ±16.62% \n     1.21 ms \n     2.03 ms \n   \n   \n     feeder_ex \n     124.28 \n     8.05 ms \n     ±6.94% \n     8.03 ms \n     10.32 ms \n   \n   \n     elixir_feed_parser \n     26.26 \n     38.09 ms \n     ±5.08% \n     37.81 ms \n     44.42 ms \n   \n   \n     feed_raptor \n     3.21 \n     311.16 ms \n     ±2.85% \n     307.86 ms \n     345.09 ms \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     760.30 \n     &nbsp; \n   \n   \n     feeder_ex \n     124.28 \n     6.12x \n   \n   \n     elixir_feed_parser \n     26.26 \n     28.96x \n   \n   \n     feed_raptor \n     3.21 \n     236.57x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00157 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     4.28 MB \n     2726.19x \n   \n   \n     elixir_feed_parser \n     35.88 MB \n     22829.92x \n   \n   \n     feed_raptor \n     274.98 MB \n     174963.99x \n   \n \n \n\n**Input: stuff**\n\nRun Time\n\n \n   \n     Name \n     IPS \n     Average \n     Devitation \n     Median \n     99th&nbsp;% \n   \n   \n     fast_rss \n     19.19 \n     0.0521 s \n     ±9.19% \n     0.0546 s \n     0.0635 s \n   \n   \n     feeder_ex \n     0.93 \n     1.07 s \n     ±2.49% \n     1.07 s \n     1.15 s \n   \n   \n     elixir_feed_parser \n     0.53 \n     1.88 s \n     ±1.22% \n     1.89 s \n     1.92 s \n   \n   \n     feed_raptor \n     0.0797 \n     12.54 s \n     ±1.61% \n     12.44 s \n     12.77 s \n   \n \nComparison\n \n   \n     Name \n     IPS \n     Slower \n   \n     fast_rss \n     19.19 \n     &nbsp; \n   \n   \n     feeder_ex \n     0.93 \n     20.59x \n   \n   \n     elixir_feed_parser \n     0.53 \n     36.11x \n   \n   \n     feed_raptor \n     0.0797 \n     240.68x \n   \n \nMemory Usage\n \n   \n     Name \n     Memory \n       Factor \n   \n   \n     fast_rss \n     0.00154 MB \n       &nbsp; \n   \n   \n     feeder_ex \n     140.58 MB \n     91220.55x \n   \n   \n     elixir_feed_parser \n     1018.78 MB \n     661058.28x \n   \n   \n     feed_raptor \n     8424.44 MB \n     5466379.81x","ref":"readme.html#statistics"},{"type":"extras","title":"Deploying - README","doc":"Deploying rust NIFs can be a little bit annoying as you have to install the rust compiler. We try to alleviate this with [`rustler_precopmiled`](https://hexdocs.pm/rustler_precompiled/RustlerPrecompiled.html), which will create precompiled assets for a number of targets (see [`release.yml`](./.github/workflows/release.yml) for the full list), but does not cover all environments. If you are having trouble deploying this package make an issue and I will try and help you out.\n\nI will then add it to the FAQ below.\n\n#","ref":"readme.html#deploying"},{"type":"extras","title":"Q. How do I deploy using an Alpine Dockerfile? - README","doc":"##","ref":"readme.html#q-how-do-i-deploy-using-an-alpine-dockerfile"},{"type":"extras","title":"A. I recommend using a [multi-stage Dockerfile](https://docs.docker.com/develop/develop-images/multistage-build/), and doing the following - README","doc":"1.  On the stages where you build all your deps, and build your release make sure to install `build-base` and `libgcc`:\n\n    ```dockerfile\n    # This step installs all the build tools we'll need\n    RUN apk update && \\\n        apk upgrade --no-cache && \\\n        apk add --no-cache \\\n        git \\\n        curl \\\n        build-base \\\n        libgcc  && \\\n        mix local.rebar --force && \\\n        mix local.hex --force\n    ```\n\n2.  Install the rust compiler and allow dynamic linking to the C library by setting the rust flag\n\n    ```dockerfile\n    # install rustup\n    RUN curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh -s -- -y\n    ENV RUSTUP_HOME=/root/.rustup \\\n        RUSTFLAGS=\"-C target-feature=-crt-static\" \\\n        CARGO_HOME=/root/.cargo  \\\n        PATH=\"/root/.cargo/bin:$PATH\"\n    ```\n\n3.  On the stage where you actually run your elixir release install `libgcc`:\n\n    ```dockerfile\n    ################################################################################","ref":"readme.html#a-i-recommend-using-a-multi-stage-dockerfile-https-docs-docker-com-develop-develop-images-multistage-build-and-doing-the-following"},{"type":"extras","title":"STEP 4 - FINAL - README","doc":"FROM alpine:3.11\n\n    ENV MIX_ENV=prod\n\n    RUN apk update && \\\n        apk add --no-cache \\\n        bash \\\n        libgcc \\\n        openssl-dev\n\n    COPY --from=release-builder /opt/built /app\n    WORKDIR /app\n    CMD [\"/app/my_app/bin/my_app\", \"start\"]\n    ```","ref":"readme.html#step-4-final"},{"type":"extras","title":"License - README","doc":"FastRSS is released under the Apache License 2.0 - see the [LICENSE](LICENSE) file.","ref":"readme.html#license"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - CHANGELOG","doc":"- Add support for parsing Atom feeds (`parse_atom/1`)\n- Deprecate `parse/1` function in favor or `parse_rss/1` function\n\n## [0.4.4] – 2022-11-25\n\n- Attempt to fix precompiled assets for case sensitive filesystems again\n\n## [0.4.3] – 2022-11-24\n\n- Fix precompiled assets for case sensitive filesystems\n\n## [0.4.2] – 2022-11-14\n\n#","ref":"changelog.html#unreleased"},{"type":"extras","title":"Internal - CHANGELOG","doc":"- Added `rustler_precompiled`, thanks [@tmr08c](https://github.com/tmr08c), [#18](https://github.com/avencera/fast_rss/pull/18)\n- Update cargo and hex deps\n\n## [0.4.1] – 2022-01-21\n\n#","ref":"changelog.html#internal"},{"type":"extras","title":"Internal - CHANGELOG","doc":"- Upgraded cargo deps\n\n## [0.4.0] – 2022-01-21\n\n#","ref":"changelog.html#internal"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Added support for OTP24, thanks [@gmile](https://github.com/gmile), [#11](https://github.com/avencera/fast_rss/pull/11)\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Internal - CHANGELOG","doc":"- Upgraded to rustler 0.23, thanks [@praveenperera](https://github.com/praveenperera), [#12](https://github.com/avencera/fast_rss/pull/12)\n\n## [0.3.5] – 2021-02-18\n\n#","ref":"changelog.html#internal"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Now compiles on M1 (arm64) macs, thanks [@29decibel](https://github.com/29decibel)\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Internal - CHANGELOG","doc":"- Updated cargo deps ([rss](https://crates.io/crates/rss) updated to v1.10.0)\n- Fixed clippy warnings\n\n## [0.3.4] – 2020-10-27\n\n- Update cargo dependencies\n\n## [0.3.3] – 2020-02-28\n\n#","ref":"changelog.html#internal"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Pass errors back as `:error` not `:unknown_error`\n\n## [0.3.2] – 2020-02-27\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Pass all errors back as `{:error, String.t()}` tuple instead of raising in some cases\n\n## [0.3.1] – 2020-02-24\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - CHANGELOG","doc":"- README to hexdocs\n- Full license to repo\n\n## [0.3.0] – 2020-02-24\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - CHANGELOG","doc":"- Use erlang dirty scheduler\n- Now requires OTP >= 20\n- Added benchmark for normal vs dirty: [normal vs dirty](bench/output/dirty_vs_normal.md)\n\n## [0.2.0] – 2020-02-22\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- **Map is returned with string keys instead of atom keys**\n- Now between 6.12x - 50.09x faster than next fastest tested option\n- Removed Jason dependency\n- Returning elixir map directly instead of returning a stringified JSON and then using Jason to convert it to an elixir map\n\n## [0.1.4] – 2020-02-21\n\n- Convert RSS feed into map with atom keys\n- Between 2.85x - 22.05x faster than next fastest tested option","ref":"changelog.html#changed"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1.  Definitions.\n\n    \"License\" shall mean the terms and conditions for use, reproduction,\n    and distribution as defined by Sections 1 through 9 of this document.\n\n    \"Licensor\" shall mean the copyright owner or entity authorized by\n    the copyright owner that is granting the License.\n\n    \"Legal Entity\" shall mean the union of the acting entity and all\n    other entities that control, are controlled by, or are under common\n    control with that entity. For the purposes of this definition,\n    \"control\" means (i) the power, direct or indirect, to cause the\n    direction or management of such entity, whether by contract or\n    otherwise, or (ii) ownership of fifty percent (50%) or more of the\n    outstanding shares, or (iii) beneficial ownership of such entity.\n\n    \"You\" (or \"Your\") shall mean an individual or Legal Entity\n    exercising permissions granted by this License.\n\n    \"Source\" form shall mean the preferred form for making modifications,\n    including but not limited to software source code, documentation\n    source, and configuration files.\n\n    \"Object\" form shall mean any form resulting from mechanical\n    transformation or translation of a Source form, including but\n    not limited to compiled object code, generated documentation,\n    and conversions to other media types.\n\n    \"Work\" shall mean the work of authorship, whether in Source or\n    Object form, made available under the License, as indicated by a\n    copyright notice that is included in or attached to the work\n    (an example is provided in the Appendix below).\n\n    \"Derivative Works\" shall mean any work, whether in Source or Object\n    form, that is based on (or derived from) the Work and for which the\n    editorial revisions, annotations, elaborations, or other modifications\n    represent, as a whole, an original work of authorship. For the purposes\n    of this License, Derivative Works shall not include works that remain\n    separable from, or merely link (or bind by name) to the interfaces of,\n    the Work and Derivative Works thereof.\n\n    \"Contribution\" shall mean any work of authorship, including\n    the original version of the Work and any modifications or additions\n    to that Work or Derivative Works thereof, that is intentionally\n    submitted to Licensor for inclusion in the Work by the copyright owner\n    or by an individual or Legal Entity authorized to submit on behalf of\n    the copyright owner. For the purposes of this definition, \"submitted\"\n    means any form of electronic, verbal, or written communication sent\n    to the Licensor or its representatives, including but not limited to\n    communication on electronic mailing lists, source code control systems,\n    and issue tracking systems that are managed by, or on behalf of, the\n    Licensor for the purpose of discussing and improving the Work, but\n    excluding communication that is conspicuously marked or otherwise\n    designated in writing by the copyright owner as \"Not a Contribution.\"\n\n    \"Contributor\" shall mean Licensor and any individual or Legal Entity\n    on behalf of whom a Contribution has been received by Licensor and\n    subsequently incorporated within the Work.\n\n2.  Grant of Copyright License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    copyright license to reproduce, prepare Derivative Works of,\n    publicly display, publicly perform, sublicense, and distribute the\n    Work and such Derivative Works in Source or Object form.\n\n3.  Grant of Patent License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    (except as stated in this section) patent license to make, have made,\n    use, offer to sell, sell, import, and otherwise transfer the Work,\n    where such license applies only to those patent claims licensable\n    by such Contributor that are necessarily infringed by their\n    Contribution(s) alone or by combination of their Contribution(s)\n    with the Work to which such Contribution(s) was submitted. If You\n    institute patent litigation against any entity (including a\n    cross-claim or counterclaim in a lawsuit) alleging that the Work\n    or a Contribution incorporated within the Work constitutes direct\n    or contributory patent infringement, then any patent licenses\n    granted to You under this License for that Work shall terminate\n    as of the date such litigation is filed.\n\n4.  Redistribution. You may reproduce and distribute copies of the\n    Work or Derivative Works thereof in any medium, with or without\n    modifications, and in Source or Object form, provided that You\n    meet the following conditions:\n\n    (a) You must give any other recipients of the Work or\n    Derivative Works a copy of this License; and\n\n    (b) You must cause any modified files to carry prominent notices\n    stating that You changed the files; and\n\n    (c) You must retain, in the Source form of any Derivative Works\n    that You distribute, all copyright, patent, trademark, and\n    attribution notices from the Source form of the Work,\n    excluding those notices that do not pertain to any part of\n    the Derivative Works; and\n\n    (d) If the Work includes a \"NOTICE\" text file as part of its\n    distribution, then any Derivative Works that You distribute must\n    include a readable copy of the attribution notices contained\n    within such NOTICE file, excluding those notices that do not\n    pertain to any part of the Derivative Works, in at least one\n    of the following places: within a NOTICE text file distributed\n    as part of the Derivative Works; within the Source form or\n    documentation, if provided along with the Derivative Works; or,\n    within a display generated by the Derivative Works, if and\n    wherever such third-party notices normally appear. The contents\n    of the NOTICE file are for informational purposes only and\n    do not modify the License. You may add Your own attribution\n    notices within Derivative Works that You distribute, alongside\n    or as an addendum to the NOTICE text from the Work, provided\n    that such additional attribution notices cannot be construed\n    as modifying the License.\n\n    You may add Your own copyright statement to Your modifications and\n    may provide additional or different license terms and conditions\n    for use, reproduction, or distribution of Your modifications, or\n    for any such Derivative Works as a whole, provided Your use,\n    reproduction, and distribution of the Work otherwise complies with\n    the conditions stated in this License.\n\n5.  Submission of Contributions. Unless You explicitly state otherwise,\n    any Contribution intentionally submitted for inclusion in the Work\n    by You to the Licensor shall be under the terms and conditions of\n    this License, without any additional terms or conditions.\n    Notwithstanding the above, nothing herein shall supersede or modify\n    the terms of any separate license agreement you may have executed\n    with Licensor regarding such Contributions.\n\n6.  Trademarks. This License does not grant permission to use the trade\n    names, trademarks, service marks, or product names of the Licensor,\n    except as required for reasonable and customary use in describing the\n    origin of the Work and reproducing the content of the NOTICE file.\n\n7.  Disclaimer of Warranty. Unless required by applicable law or\n    agreed to in writing, Licensor provides the Work (and each\n    Contributor provides its Contributions) on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n    implied, including, without limitation, any warranties or conditions\n    of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n    PARTICULAR PURPOSE. You are solely responsible for determining the\n    appropriateness of using or redistributing the Work and assume any\n    risks associated with Your exercise of permissions under this License.\n\n8.  Limitation of Liability. In no event and under no legal theory,\n    whether in tort (including negligence), contract, or otherwise,\n    unless required by applicable law (such as deliberate and grossly\n    negligent acts) or agreed to in writing, shall any Contributor be\n    liable to You for damages, including any direct, indirect, special,\n    incidental, or consequential damages of any character arising as a\n    result of this License or out of the use or inability to use the\n    Work (including but not limited to damages for loss of goodwill,\n    work stoppage, computer failure or malfunction, or any and all\n    other commercial damages or losses), even if such Contributor\n    has been advised of the possibility of such damages.\n\n9.  Accepting Warranty or Additional Liability. While redistributing\n    the Work or Derivative Works thereof, You may choose to offer,\n    and charge a fee for, acceptance of support, warranty, indemnity,\n    or other liability obligations and/or rights consistent with this\n    License. However, in accepting such obligations, You may act only\n    on Your own behalf and on Your sole responsibility, not on behalf\n    of any other Contributor, and only if You agree to indemnify,\n    defend, and hold each Contributor harmless for any liability\n    incurred by, or claims asserted against, such Contributor by reason\n    of your accepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"license.html"}],"content_type":"text/markdown"}